<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>AppLauncher</name>
    <message>
        <location filename="../../src/tools/launcher/applaunchertool.cpp" line="40"/>
        <source>App Launcher</source>
        <translation>Iniciar app</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applaunchertool.cpp" line="52"/>
        <source>Choose an app to open the capture</source>
        <translation>Escolha uma aplicação para abrir a captura</translation>
    </message>
</context>
<context>
    <name>AppLauncherWidget</name>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="56"/>
        <source>Open With</source>
        <translation>Abrir Com</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="71"/>
        <source>Launch in terminal</source>
        <translation>Abrir no terminal</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="72"/>
        <source>Keep open after selection</source>
        <translation>Manter aberto após seleção</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="109"/>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="124"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="109"/>
        <source>Unable to write in</source>
        <translation>Não é possível escrever em</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="124"/>
        <source>Unable to launch in terminal.</source>
        <translation>Não foi possível abrir no terminal.</translation>
    </message>
</context>
<context>
    <name>ArrowTool</name>
    <message>
        <location filename="../../src/tools/arrow/arrowtool.cpp" line="92"/>
        <source>Arrow</source>
        <translation>Flecha</translation>
    </message>
    <message>
        <location filename="../../src/tools/arrow/arrowtool.cpp" line="104"/>
        <source>Set the Arrow as the paint tool</source>
        <translation>Usar a Flecha como ferramenta de desenho</translation>
    </message>
</context>
<context>
    <name>BlurTool</name>
    <message>
        <source>Blur</source>
        <translation type="vanished">Desfoque</translation>
    </message>
    <message>
        <source>Set Blur as the paint tool</source>
        <translation type="vanished">Usar o Desfoque como ferramenta de desenho</translation>
    </message>
</context>
<context>
    <name>CaptureLauncher</name>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="67"/>
        <source>&lt;b&gt;Capture Mode&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="73"/>
        <source>Rectangular Region</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="75"/>
        <source>Full Screen (All Monitors)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="83"/>
        <source>No Delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="90"/>
        <source> second</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="90"/>
        <source> seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="94"/>
        <source>Take new screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="103"/>
        <source>Area:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="104"/>
        <source>Delay:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CaptureWidget</name>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="99"/>
        <source>Unable to capture screen</source>
        <translation>Não foi possível capturar a tela</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="260"/>
        <source>Select an area with the mouse, or press Esc to exit.
Press Enter to capture the screen.
Press Right Click to show the color picker.
Use the Mouse Wheel to change the thickness of your tool.
Press Space to open the side panel.</source>
        <translation>Selecione uma área com o mouse, ou precione Esc para sair.
Pressione Enter para capturar a tela.
Pressione o botão direito do mouse para abrir o seletor de cores.
Use a roda do mouse para aumentar a grossura do pincel.
Pressione espaço abrir o painel lateral.</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="617"/>
        <source>Tool Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CircleCountTool</name>
    <message>
        <location filename="../../src/tools/circlecount/circlecounttool.cpp" line="39"/>
        <source>Circle Counter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/tools/circlecount/circlecounttool.cpp" line="51"/>
        <source>Add an autoincrementing counter bubble</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CircleTool</name>
    <message>
        <location filename="../../src/tools/circle/circletool.cpp" line="40"/>
        <source>Circle</source>
        <translation>Círculo</translation>
    </message>
    <message>
        <location filename="../../src/tools/circle/circletool.cpp" line="52"/>
        <source>Set the Circle as the paint tool</source>
        <translation>Usar o Círculo como ferramenta de desenho</translation>
    </message>
</context>
<context>
    <name>ConfigWindow</name>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="43"/>
        <source>Configuration</source>
        <translation>Configuração</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="63"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="69"/>
        <source>Filename Editor</source>
        <translation>Editor de nome de arquivo</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="73"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <location filename="../../src/core/controller.cpp" line="204"/>
        <source>&amp;Take Screenshot</source>
        <translation>&amp;Tirar Screenshot</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="209"/>
        <source>&amp;Open Launcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="212"/>
        <source>&amp;Configuration</source>
        <translation>&amp;Configuração</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="215"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation type="vanished">&amp;Informações</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="217"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
</context>
<context>
    <name>CopyTool</name>
    <message>
        <location filename="../../src/tools/copy/copytool.cpp" line="41"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../../src/tools/copy/copytool.cpp" line="53"/>
        <source>Copy the selection into the clipboard</source>
        <translation>Copia a seleção para a área de transferência</translation>
    </message>
</context>
<context>
    <name>DBusUtils</name>
    <message>
        <location filename="../../src/utils/dbusutils.cpp" line="52"/>
        <source>Unable to connect via DBus</source>
        <translation>Não foi possível conectar via DBus</translation>
    </message>
</context>
<context>
    <name>ExitTool</name>
    <message>
        <location filename="../../src/tools/exit/exittool.cpp" line="40"/>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../../src/tools/exit/exittool.cpp" line="52"/>
        <source>Leave the capture screen</source>
        <translation>Sair da ferramenta de captura</translation>
    </message>
</context>
<context>
    <name>FileNameEditor</name>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="39"/>
        <source>Edit the name of your captures:</source>
        <translation>Edite o nome das suas capturas:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="43"/>
        <source>Edit:</source>
        <translation>Editar:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="45"/>
        <source>Preview:</source>
        <translation>Preview:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="88"/>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="91"/>
        <source>Saves the pattern</source>
        <translation>Salva o padrão</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="93"/>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="96"/>
        <source>Restores the saved pattern</source>
        <translation>Restaura o padrão salvo</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="98"/>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="102"/>
        <source>Deletes the name</source>
        <translation>Deleta o nome</translation>
    </message>
</context>
<context>
    <name>GeneneralConf</name>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="121"/>
        <location filename="../../src/config/geneneralconf.cpp" line="258"/>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="128"/>
        <location filename="../../src/config/geneneralconf.cpp" line="136"/>
        <location filename="../../src/config/geneneralconf.cpp" line="160"/>
        <location filename="../../src/config/geneneralconf.cpp" line="370"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="128"/>
        <source>Unable to read file.</source>
        <translation>Não foi possível ler o arquivo.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="136"/>
        <location filename="../../src/config/geneneralconf.cpp" line="160"/>
        <source>Unable to write file.</source>
        <translation>Não foi possível escrever no arquivo.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="147"/>
        <source>Save File</source>
        <translation>Salvar Arquivo</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="170"/>
        <source>Confirm Reset</source>
        <translation>Confirmar Reset</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="171"/>
        <source>Are you sure you want to reset the configuration?</source>
        <translation>Tem certeza que deseja resetar a configuração?</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="181"/>
        <source>Show help message</source>
        <translation>Mostrar mensagem de ajuda</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="185"/>
        <source>Show the help message at the beginning in the capture mode.</source>
        <translation>Mostrar mensagem de ajuda no início do modo de captura.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="196"/>
        <source>Show the side panel button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="199"/>
        <source>Show the side panel toggle button in the capture mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="210"/>
        <location filename="../../src/config/geneneralconf.cpp" line="214"/>
        <source>Show desktop notifications</source>
        <translation>Mostrar notificações de Desktop</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="227"/>
        <source>Show tray icon</source>
        <translation>Mostrar ícone de tray</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="231"/>
        <source>Show the systemtray icon</source>
        <translation>Mosrar ícone na barra de aplicações</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="246"/>
        <source>Configuration File</source>
        <translation>Arquivo de Configurações</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="251"/>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="265"/>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="276"/>
        <source>Launch at startup</source>
        <translation>Iniciar junto com o sistema</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="280"/>
        <source>Launch Flameshot</source>
        <translation>Iniciar Flameshot</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="290"/>
        <source>Close after capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="294"/>
        <source>Close after taking a screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="306"/>
        <source>Copy URL after upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="311"/>
        <source>Copy URL and close window after upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="322"/>
        <source>Save image after copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="323"/>
        <source>Save image file after copying it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="332"/>
        <source>Save Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="344"/>
        <source>Change...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="363"/>
        <source>Choose a Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="370"/>
        <source>Unable to write to directory.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="48"/>
        <source>Upload to Imgur</source>
        <translation>Upload no Imgur</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="55"/>
        <source>Uploading Image</source>
        <translation>Upando Imagem</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="156"/>
        <source>Copy URL</source>
        <translation>Copiar URL</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="157"/>
        <source>Open URL</source>
        <translation>Abrir URL</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="158"/>
        <source>Delete image</source>
        <translation>Deletar imagem</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="159"/>
        <source>Image to Clipboard.</source>
        <translation>Imagem na área de transferência.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="184"/>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="200"/>
        <source>Unable to open the URL.</source>
        <translation>Não foi possível abrir a URL.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="192"/>
        <source>URL copied to clipboard.</source>
        <translation>URL copiada para a área de transferência.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="208"/>
        <source>Screenshot copied to clipboard.</source>
        <translation>Screenshot copiada para a área de transferência.</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderTool</name>
    <message>
        <location filename="../../src/tools/imgur/imguruploadertool.cpp" line="41"/>
        <source>Image Uploader</source>
        <translation>Uploader de imagens</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploadertool.cpp" line="53"/>
        <source>Upload the selection to Imgur</source>
        <translation>Upa a seleção no Imgur</translation>
    </message>
</context>
<context>
    <name>InfoWindow</name>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="40"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="62"/>
        <source>SPACEBAR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="63"/>
        <source>Right Click</source>
        <translation>Botão Direito</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="64"/>
        <source>Mouse Wheel</source>
        <translation>Roda do mouse</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="67"/>
        <source>Move selection 1px</source>
        <translation>Move a seleção em 1px</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="68"/>
        <source>Resize selection 1px</source>
        <translation>Redimensiona a seleção em 1px</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="69"/>
        <source>Quit capture</source>
        <translation>Sair da captura</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="70"/>
        <source>Copy to clipboard</source>
        <translation>Copiar para área de transferência</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="71"/>
        <source>Save selection as a file</source>
        <translation>Salvar seleção em um arquivo</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="72"/>
        <source>Undo the last modification</source>
        <translation>Desfazer última modificação</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="73"/>
        <source>Toggle visibility of sidebar with options of the selected tool</source>
        <translation>Alterar barra lateral com as opções da ferramenta selecionada</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="74"/>
        <source>Show color picker</source>
        <translation>Mostrar seletor de cores</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="75"/>
        <source>Change the tool&apos;s thickness</source>
        <translation>Mudar a grossura do pincel</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="82"/>
        <source>Available shortcuts in the screen capture mode.</source>
        <translation>Atalhos disponívels na tela de captura.</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="93"/>
        <source>Key</source>
        <translation>Tecla</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="93"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="126"/>
        <source>&lt;u&gt;&lt;b&gt;License&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;Licença&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="134"/>
        <source>&lt;u&gt;&lt;b&gt;Version&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;Versão&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="145"/>
        <source>&lt;u&gt;&lt;b&gt;Shortcuts&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;Atalhos&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
</context>
<context>
    <name>LineTool</name>
    <message>
        <location filename="../../src/tools/line/linetool.cpp" line="43"/>
        <source>Line</source>
        <translation>Linha</translation>
    </message>
    <message>
        <location filename="../../src/tools/line/linetool.cpp" line="55"/>
        <source>Set the Line as the paint tool</source>
        <translation>Usar a Linha como ferramenta de desenho</translation>
    </message>
</context>
<context>
    <name>MarkerTool</name>
    <message>
        <location filename="../../src/tools/marker/markertool.cpp" line="43"/>
        <source>Marker</source>
        <translation>Marcador</translation>
    </message>
    <message>
        <location filename="../../src/tools/marker/markertool.cpp" line="55"/>
        <source>Set the Marker as the paint tool</source>
        <translation>Usar o marcador como ferramenta de desenho</translation>
    </message>
</context>
<context>
    <name>MoveTool</name>
    <message>
        <location filename="../../src/tools/move/movetool.cpp" line="40"/>
        <source>Move</source>
        <translation>Mover</translation>
    </message>
    <message>
        <location filename="../../src/tools/move/movetool.cpp" line="52"/>
        <source>Move the selection area</source>
        <translation>Mover a área de seleção</translation>
    </message>
</context>
<context>
    <name>PencilTool</name>
    <message>
        <location filename="../../src/tools/pencil/penciltool.cpp" line="34"/>
        <source>Pencil</source>
        <translation>Pincel</translation>
    </message>
    <message>
        <location filename="../../src/tools/pencil/penciltool.cpp" line="46"/>
        <source>Set the Pencil as the paint tool</source>
        <translation>Usar o Lápis como ferramenta de desenho</translation>
    </message>
</context>
<context>
    <name>PinTool</name>
    <message>
        <location filename="../../src/tools/pin/pintool.cpp" line="40"/>
        <source>Pin Tool</source>
        <translation>Ferramenta de fixação</translation>
    </message>
    <message>
        <location filename="../../src/tools/pin/pintool.cpp" line="52"/>
        <source>Pin image on the desktop</source>
        <translation>Fixar imagem no desktop</translation>
    </message>
</context>
<context>
    <name>PixelateTool</name>
    <message>
        <location filename="../../src/tools/pixelate/pixelatetool.cpp" line="40"/>
        <source>Pixelate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/tools/pixelate/pixelatetool.cpp" line="52"/>
        <source>Set Pixelate as the paint tool</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="112"/>
        <source>Save Error</source>
        <translation>Erro ao salvar</translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="66"/>
        <location filename="../../src/utils/screenshotsaver.cpp" line="107"/>
        <source>Capture saved as </source>
        <translation>Captura salva como </translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="42"/>
        <source>Capture saved to clipboard.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="47"/>
        <source>Capture saved to clipboard</source>
        <translation>Captura salva na área de transferência</translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="69"/>
        <location filename="../../src/utils/screenshotsaver.cpp" line="110"/>
        <source>Error trying to save as </source>
        <translation>Erro ao tentar salvar como </translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="82"/>
        <location filename="../../src/main.cpp" line="244"/>
        <location filename="../../src/main.cpp" line="399"/>
        <location filename="../../src/main.cpp" line="426"/>
        <location filename="../../src/main.cpp" line="458"/>
        <source>Unable to connect via DBus</source>
        <translation>Não foi possível conectar via DBus</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="104"/>
        <source>Powerful yet simple to use screenshot software.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="105"/>
        <source>See</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="108"/>
        <source>Capture the entire desktop.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="110"/>
        <source>Open the capture launcher.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="112"/>
        <source>Start a manual capture in GUI mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="114"/>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="116"/>
        <source>Capture a single screen.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="120"/>
        <source>Path where the capture will be saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="123"/>
        <source>Save the capture to the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="125"/>
        <source>Delay time in milliseconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="128"/>
        <source>Set the filename pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="131"/>
        <source>Enable or disable the trayicon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="134"/>
        <source>Enable or disable run at startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="138"/>
        <source>Show the help message in the capture mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="141"/>
        <source>Define the main UI color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="144"/>
        <source>Define the contrast UI color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="147"/>
        <source>Print raw PNG capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="150"/>
        <source>Define the screen to capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="151"/>
        <source>default: screen containing the cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="152"/>
        <source>Screen number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="161"/>
        <source>Invalid color, this flag supports the following formats:
- #RGB (each of R, G, and B is a single hex digit)
- #RRGGBB
- #RRRGGGBBB
- #RRRRGGGGBBBB
- Named colors like &apos;blue&apos; or &apos;red&apos;
You may need to escape the &apos;#&apos; sign as in &apos;\#FFF&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="170"/>
        <source>Invalid delay, it must be higher than 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="172"/>
        <source>Invalid screen number, it must be non negative</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="179"/>
        <source>Invalid path, it must be a real path in the system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="189"/>
        <source>Invalid value, it must be defined as &apos;true&apos; or &apos;false&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/openwithprogram.cpp" line="45"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/openwithprogram.cpp" line="46"/>
        <source>Unable to write in</source>
        <translation>Não foi possível escrever em</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="64"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="77"/>
        <source>Arguments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="350"/>
        <source>arguments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="351"/>
        <source>Usage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="351"/>
        <source>options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="358"/>
        <source>Per default runs Flameshot in the background and   adds a tray icon for configuration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="88"/>
        <source>URL copied to clipboard.</source>
        <translation type="unfinished">URL copiada para a área de transferência.</translation>
    </message>
</context>
<context>
    <name>RectangleTool</name>
    <message>
        <location filename="../../src/tools/rectangle/rectangletool.cpp" line="40"/>
        <source>Rectangle</source>
        <translation>Retângulo</translation>
    </message>
    <message>
        <location filename="../../src/tools/rectangle/rectangletool.cpp" line="52"/>
        <source>Set the Rectangle as the paint tool</source>
        <translation>Usar o Retângulo como ferramenta de desenho</translation>
    </message>
</context>
<context>
    <name>RedoTool</name>
    <message>
        <location filename="../../src/tools/redo/redotool.cpp" line="40"/>
        <source>Redo</source>
        <translation>Refazer</translation>
    </message>
    <message>
        <location filename="../../src/tools/redo/redotool.cpp" line="52"/>
        <source>Redo the next modification</source>
        <translation>Refazer última modificação</translation>
    </message>
</context>
<context>
    <name>SaveTool</name>
    <message>
        <location filename="../../src/tools/save/savetool.cpp" line="41"/>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../../src/tools/save/savetool.cpp" line="53"/>
        <source>Save the capture</source>
        <translation>Salvar a captura</translation>
    </message>
</context>
<context>
    <name>ScreenGrabber</name>
    <message>
        <location filename="../../src/utils/screengrabber.cpp" line="84"/>
        <source>Unable to capture screen</source>
        <translation>Não foi possível capturar a tela</translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <location filename="../../src/tools/selection/selectiontool.cpp" line="46"/>
        <source>Rectangular Selection</source>
        <translation>Seleção Retangular</translation>
    </message>
    <message>
        <location filename="../../src/tools/selection/selectiontool.cpp" line="58"/>
        <source>Set Selection as the paint tool</source>
        <translation>Usar o Selecionador como ferramenta de desenho</translation>
    </message>
</context>
<context>
    <name>SidePanelWidget</name>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="71"/>
        <source>Active thickness:</source>
        <translation>Grossura:</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="72"/>
        <source>Active color:</source>
        <translation>Cor:</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="217"/>
        <source>Press ESC to cancel</source>
        <translation>Presione Esc para cancelar</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="219"/>
        <source>Grab Color</source>
        <translation>Usar Cor</translation>
    </message>
</context>
<context>
    <name>SizeIndicatorTool</name>
    <message>
        <location filename="../../src/tools/sizeindicator/sizeindicatortool.cpp" line="40"/>
        <source>Selection Size Indicator</source>
        <translation>Indicador do Tamanho da Seleção</translation>
    </message>
    <message>
        <location filename="../../src/tools/sizeindicator/sizeindicatortool.cpp" line="52"/>
        <source>Show the dimensions of the selection (X Y)</source>
        <translation>Mostra as dimenções da seleção (X Y)</translation>
    </message>
</context>
<context>
    <name>StrftimeChooserWidget</name>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="50"/>
        <source>Century (00-99)</source>
        <translation>Século (00-99)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="51"/>
        <source>Year (00-99)</source>
        <translation>Ano (00-99)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="52"/>
        <source>Year (2000)</source>
        <translation>Ano (2000)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="53"/>
        <source>Month Name (jan)</source>
        <translation>Nome do mês (jan)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="54"/>
        <source>Month Name (january)</source>
        <translation>Nome do mês (janeiro)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="55"/>
        <source>Month (01-12)</source>
        <translation>Mês (01-12)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="56"/>
        <source>Week Day (1-7)</source>
        <translation>Dia da semana (1-7)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="57"/>
        <source>Week (01-53)</source>
        <translation>Semana (01-53)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="58"/>
        <source>Day Name (mon)</source>
        <translation>Nome do dia (seg)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="59"/>
        <source>Day Name (monday)</source>
        <translation>Nome do dia (segunda)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="60"/>
        <source>Day (01-31)</source>
        <translation>Dia (01-31)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="61"/>
        <source>Day of Month (1-31)</source>
        <translation>Dia do Mês (1-31)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="62"/>
        <source>Day (001-366)</source>
        <translation>Dia (001-366)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="63"/>
        <source>Time (%H-%M-%S)</source>
        <translation>Tempo (%H-%M-%S)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="64"/>
        <source>Time (%H-%M)</source>
        <translation>Tempo (%H-%M)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="65"/>
        <source>Hour (00-23)</source>
        <translation>Hora (00-23)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="66"/>
        <source>Hour (01-12)</source>
        <translation>Hora (01-12)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="67"/>
        <source>Minute (00-59)</source>
        <translation>Minuto (00-59)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="68"/>
        <source>Second (00-59)</source>
        <translation>Segundo (00-59)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="69"/>
        <source>Full Date (%m/%d/%y)</source>
        <translation>Data Completa (%m/%d/%y)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="70"/>
        <source>Full Date (%Y-%m-%d)</source>
        <translation>Data Completa (%Y-%m-%d)</translation>
    </message>
</context>
<context>
    <name>SystemNotification</name>
    <message>
        <location filename="../../src/utils/systemnotification.cpp" line="36"/>
        <source>Flameshot Info</source>
        <translation>Informações do Flameshot</translation>
    </message>
</context>
<context>
    <name>TextConfig</name>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="54"/>
        <source>StrikeOut</source>
        <translation>Sobrescrito</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="63"/>
        <source>Underline</source>
        <translation>Sublinhado</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="72"/>
        <source>Bold</source>
        <translation>Negrito</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="81"/>
        <source>Italic</source>
        <translation>Itálico</translation>
    </message>
</context>
<context>
    <name>TextTool</name>
    <message>
        <location filename="../../src/tools/text/texttool.cpp" line="63"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/texttool.cpp" line="75"/>
        <source>Add text to your capture</source>
        <translation>Adicionar texto à captura</translation>
    </message>
</context>
<context>
    <name>UIcolorEditor</name>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="32"/>
        <source>UI Color Editor</source>
        <translation>Interface de Edição de Cores</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="107"/>
        <source>Change the color moving the selectors and see the changes in the preview buttons.</source>
        <translation>Modifique a cor movendo os seletores e veja as mudanças nos botões de preview.</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="119"/>
        <source>Select a Button to modify it</source>
        <translation>Selecione um botão para modificá-lo</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="129"/>
        <source>Main Color</source>
        <translation>Cor Principal</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="133"/>
        <source>Click on this button to set the edition mode of the main color.</source>
        <translation>Clique neste botão para setar o modo de edição da cor principal.</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="144"/>
        <source>Contrast Color</source>
        <translation>Cor de Contraste</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="149"/>
        <source>Click on this button to set the edition mode of the contrast color.</source>
        <translation>Clique neste botão para setar o modo de edição da cor de contraste.</translation>
    </message>
</context>
<context>
    <name>UndoTool</name>
    <message>
        <location filename="../../src/tools/undo/undotool.cpp" line="40"/>
        <source>Undo</source>
        <translation>Desfazer</translation>
    </message>
    <message>
        <location filename="../../src/tools/undo/undotool.cpp" line="52"/>
        <source>Undo the last modification</source>
        <translation>Desfazer a última modificação</translation>
    </message>
</context>
<context>
    <name>UtilityPanel</name>
    <message>
        <location filename="../../src/widgets/panel/utilitypanel.cpp" line="114"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VisualsEditor</name>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="61"/>
        <source>Opacity of area outside selection:</source>
        <translation>Opacidade da área de seleção:</translation>
    </message>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="89"/>
        <source>Button Selection</source>
        <translation>Botão de seleção</translation>
    </message>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="95"/>
        <source>Select All</source>
        <translation>Selecionar Todos</translation>
    </message>
</context>
</TS>
